@@ -6,28 +6,30 @@
 #' @examples
 #'
 #' highchart() %>%
-#'   hc_add_series(data = abs(rnorm(5)), type = "columnn") %>%
-#'   hc_add_series(data = purrr::map(0:4, function(x) list(x, x)), type = "scatter", color = "blue")
+#'   hc_add_series(data = abs(rnorm(5)), type = "column") %>%
+#'   hc_add_series(data = purrr::map(0:4, function(x) list(x, x)), type = "scatter", color = "orange")
 #' @export
 hc_add_series <- function(hc, data = NULL, ...) {
-  assertthat::assert_that(is.highchart(hc))
-  
+
+  # assertthat::assert_that(is.highchart(hc))
+
   UseMethod("hc_add_series", data)
 }
 
 
 #' @export
 hc_add_series.default <- function(hc, ...) {
-  assertthat::assert_that(is.highchart(hc))
-  
+
+  # assertthat::assert_that(is.highchart(hc))
+
   if (getOption("highcharter.verbose")) {
     message("hc_add_series.default")
   }
-  
+
   validate_args("add_series", eval(substitute(alist(...))))
-  
+
   hc$x$hc_opts$series <- append(hc$x$hc_opts$series, list(list(...)))
-  
+
   hc
 }
 
@@ -41,9 +43,9 @@ hc_add_series.numeric <- function(hc, data, ...) {
   if (getOption("highcharter.verbose")) {
     message("hc_add_series.numeric")
   }
-  
+
   data <- fix_1_length_data(data)
-  
+
   hc_add_series.default(hc, data = data, ...)
 }
 
@@ -59,15 +61,15 @@ hc_add_series.ts <- function(hc, data, ...) {
   if (getOption("highcharter.verbose")) {
     message("hc_add_series.ts")
   }
-  
+
   # http://stackoverflow.com/questions/29202021/
   timestamps <- data %>%
     stats::time() %>%
     zoo::as.Date() %>%
     datetime_to_timestamp()
-  
+
   series <- list_parse2(data.frame(timestamps, as.vector(data)))
-  
+
   hc_add_series(hc, data = series, ...)
 }
 
@@ -83,15 +85,15 @@ hc_add_series.xts <- function(hc, data, ...) {
   if (getOption("highcharter.verbose")) {
     message("hc_add_series.xts")
   }
-  
+
   if (is.OHLC(data)) {
     return(hc_add_series.ohlc(hc, data, ...))
   }
-  
+
   timestamps <- datetime_to_timestamp(time(data))
-  
+
   series <- list_parse2(data.frame(timestamps, as.vector(data)))
-  
+
   hc_add_series(hc, data = series, ...)
 }
 
@@ -103,18 +105,18 @@ hc_add_series.ohlc <- function(hc, data, type = "candlestick", ...) {
   if (getOption("highcharter.verbose")) {
     message("hc_add_series.xts.ohlc")
   }
-  
+
   time <- datetime_to_timestamp(time(data))
   xdf <- cbind(time, as.data.frame(
     quantmod::OHLC(data)
   ))
   xds <- list_parse2(xdf)
-  
+
   nm <- ifelse(!is.null(list(...)[["name"]]),
-               list(...)[["name"]],
-               str_extract(names(data)[1], "^[A-Za-z]+")
+    list(...)[["name"]],
+    str_extract(names(data)[1], "^[A-Za-z]+")
   )
-  
+
   hc_add_series(hc, data = xds, name = nm, type = type, ...)
 }
 
@@ -127,35 +129,35 @@ hc_add_series.ohlc <- function(hc, data, type = "candlestick", ...) {
 #' @param fillOpacity The opacity of bands.
 #' @param name The name of the series.
 #' @param ... Arguments defined in
-#'   \url{http://api.highcharts.com/highcharts#chart}.
+#'   \url{https://api.highcharts.com/highcharts/chart}.
 #' @export
 hc_add_series.forecast <- function(hc, data, addOriginal = FALSE,
                                    addLevels = TRUE, fillOpacity = 0.1, name = NULL, ...) {
   if (getOption("highcharter.verbose")) {
     message("hc_add_series.forecast")
   }
-  
+
   rid <- random_id()
   method <- data$method
-  
+
   if (addOriginal) {
     hc <- hc_add_series(hc, data$x, name = ifelse(is.null(name), method, name), zIndex = 3, ...)
   }
-  
-  
+
+
   hc <- hc_add_series(hc, data$mean, name = ifelse(is.null(name), method, name), zIndex = 2, id = rid, ...)
-  
+
   if (addLevels) {
     tmf <- datetime_to_timestamp(zoo::as.Date(time(data$mean)))
     nmf <- paste(ifelse(is.null(name), method, name), "level", data$level)
-    
+
     for (m in seq(ncol(data$upper))) {
       dfbands <- tibble(
         t = tmf,
         l = as.vector(data$lower[, m]),
         u = as.vector(data$upper[, m])
       )
-      
+
       hc <- hc %>%
         hc_add_series(
           data = list_parse2(dfbands),
@@ -169,8 +171,8 @@ hc_add_series.forecast <- function(hc, data, addOriginal = FALSE,
         )
     }
   }
-  
-  
+
+
   hc
 }
 
@@ -184,9 +186,9 @@ hc_add_series.density <- function(hc, data, ...) {
   if (getOption("highcharter.verbose")) {
     message("hc_add_series.density")
   }
-  
+
   data <- list_parse(data.frame(cbind(x = data$x, y = data$y)))
-  
+
   hc_add_series(hc, data = data, ...)
 }
 
@@ -200,13 +202,13 @@ hc_add_series.character <- function(hc, data, ...) {
   if (getOption("highcharter.verbose")) {
     message("hc_add_series.character")
   }
-  
+
   series <- data %>%
     table() %>%
     as.data.frame(stringsAsFactors = FALSE) %>%
     setNames(c("name", "y")) %>%
     list_parse()
-  
+
   hc_add_series(hc, data = series, ...)
 }
 
@@ -225,9 +227,9 @@ hc_add_series.geo_json <- function(hc, data, type = NULL, ...) {
   if (getOption("highcharter.verbose")) {
     message("hc_add_series.geo_json")
   }
-  
+
   stopifnot(hc$x$type == "map", !is.null(type))
-  
+
   hc_add_series.default(hc, data = data, geojson = TRUE, type = type, ...)
 }
 
@@ -237,9 +239,9 @@ hc_add_series.geo_list <- function(hc, data, type = NULL, ...) {
   if (getOption("highcharter.verbose")) {
     message("hc_add_series.geo_list")
   }
-  
+
   stopifnot(hc$x$type == "map", !is.null(type))
-  
+
   hc_add_series.default(hc, data = data, geojson = TRUE, type = type, ...)
 }
 
@@ -250,7 +252,7 @@ hc_add_series.geo_list <- function(hc, data, type = NULL, ...) {
 #' @param color A stringr color.
 #' @param fillOpacity fillOpacity to the confidence interval.
 #' @param ... Arguments defined in
-#'   \url{http://api.highcharts.com/highcharts#chart}.
+#'   \url{https://api.highcharts.com/highcharts/chart}.
 #' @importFrom broom augment
 #' @importFrom rlang .data
 #' @export
@@ -258,7 +260,7 @@ hc_add_series.lm <- function(hc, data, type = "line", color = "#5F83EE", fillOpa
   if (getOption("highcharter.verbose")) {
     message(sprintf("hc_add_series.%s", class(data)))
   }
-  
+
   data2 <- data %>%
     augment() %>%
     as.matrix.data.frame() %>%
@@ -267,22 +269,22 @@ hc_add_series.lm <- function(hc, data, type = "line", color = "#5F83EE", fillOpa
   data2 <- arrange_(data2, .dots = names(data2)[2])
   data2 <- mutate(data2, x = names(data2)[2])
   data2 <- select(data2, !!!c(names(data2)[1]), .data$x, .data$.fitted, .data$.se.fit)
-  
+
   rid <- random_id()
-  
+
   hc %>%
     hc_add_series(data2,
-                  type = type, hcaes_("x", ".fitted"),
-                  id = rid, color = color, ...
+      type = type, hcaes_("x", ".fitted"),
+      id = rid, color = color, ...
     ) %>%
     hc_add_series(data2,
-                  type = "arearange",
-                  hcaes_("x",
-                         low = ".fitted - 2 * .se.fit",
-                         high = ".fitted + 2 * .se.fit"
-                  ),
-                  color = hex_to_rgba(color, fillOpacity),
-                  linkedTo = rid, zIndex = -2, ...
+      type = "arearange",
+      hcaes_("x",
+        low = ".fitted - 2 * .se.fit",
+        high = ".fitted + 2 * .se.fit"
+      ),
+      color = hex_to_rgba(color, fillOpacity),
+      linkedTo = rid, zIndex = -2, ...
     )
 }
 
@@ -297,7 +299,7 @@ hc_add_series.loess <- hc_add_series.lm
 #' @param mapping The mapping, same idea as \code{ggplot2}.
 #' @param fast convert to json during the composition of a highchart object
 #' @param ... Arguments defined in
-#'   \url{http://api.highcharts.com/highcharts#chart}.
+#'   \url{https://api.highcharts.com/highcharts/chart}.
 #' @importFrom rlang .data
 #' @export
 hc_add_series.data.frame <- function(hc, data, type = NULL, mapping = hcaes(), fast = FALSE, ...) {
@@ -309,14 +311,14 @@ hc_add_series.data.frame <- function(hc, data, type = NULL, mapping = hcaes(), f
     if (has_name(data, "series")) {
       data <- rename(data, seriess = .data$series)
     }
-    
+
     return(hc_add_series(hc, data = list_parse(data), type = type, ...))
   }
-  
+
   data <- mutate_mapping(data, mapping)
-  
+
   series <- data_to_series(data, mapping, type = type, fast = fast, ...)
-  
+
   hc_add_series_list(hc, series)
 }
 
@@ -333,13 +335,13 @@ hc_add_series.data.frame <- function(hc, data, type = NULL, mapping = hcaes(), f
 hcaes <- function(x, y, ...) {
   # taken from https://github.com/tidyverse/ggplot2/commit/d69762269787ed0799ab4fb1f35638cc46b5b7e6
   exprs <- rlang::enexprs(x = x, y = y, ...)
-  
+
   is_missing <- vapply(exprs, rlang::is_missing, logical(1))
-  
+
   mapping <- structure(exprs[!is_missing], class = "uneval")
-  
+
   class(mapping) <- c("hcaes", class(mapping))
-  
+
   mapping
 }
 
@@ -355,15 +357,15 @@ hcaes <- function(x, y, ...) {
 #' @export
 hcaes_string <- function(x, y, ...) {
   mapping <- list(...)
-  
+
   if (!missing(x)) {
     mapping["x"] <- list(x)
   }
-  
+
   if (!missing(y)) {
     mapping["y"] <- list(y)
   }
-  
+
   mapping <- lapply(mapping, function(x) {
     if (is.character(x)) {
       parse(text = x)[[1]]
@@ -372,13 +374,13 @@ hcaes_string <- function(x, y, ...) {
       x
     }
   })
-  
+
   mapping <- structure(mapping, class = "uneval")
-  
+
   mapping <- mapping[names(mapping) != ""]
-  
+
   class(mapping) <- c("hcaes", class(mapping))
-  
+
   mapping
 }
 
@@ -402,48 +404,48 @@ hcaes_ <- hcaes_string
 #' @export
 mutate_mapping <- function(data, mapping, drop = FALSE) {
   stopifnot(is.data.frame(data), inherits(mapping, "hcaes"), inherits(drop, "logical"))
-  
+
   # https://stackoverflow.com/questions/45359917/dplyr-0-7-equivalent-for-deprecated-mutate
   # https://www.johnmackintosh.com/2018-02-19-theory-free-tidyeval/
-  
+
   tran <- as.character(mapping)
   newv <- names(mapping)
   list_names <- setNames(tran, newv) %>% lapply(rlang::parse_quo, env = globalenv())
-  
+
   data <- dplyr::mutate(data, !!!list_names)
   # Reserverd  highcharts names (#241)
   if (has_name(data, "series")) {
     data <- dplyr::rename(data, seriess = .data$series)
   }
-  
+
   if (drop) {
     newv <- rlang::syms(newv)
     data <- dplyr::select(data, !!!newv)
   }
-  
+
   data
 }
 
 add_arg_to_df <- function(data, ...) {
   datal <- as.list(data)
-  
+
   l <- map_if(list(...), function(x) is.list(x), list)
-  
+
   datal <- append(datal, l)
-  
+
   as_tibble(datal)
 }
 
 #' @importFrom dplyr mutate do arrange_
 #' @importFrom tibble tibble tibble_
 data_to_series <- function(data, mapping, type, fast = FALSE, ...) {
-  
+
   # check type and fix
   type <- ifelse(type == "point", "scatter", type)
   type <- ifelse((has_name(mapping, "size") | has_name(mapping, "z")) & type == "scatter",
-                 "bubble", type
+    "bubble", type
   )
-  
+
   # heatmap
   if (type == "heatmap") {
     if (!is.numeric(data[["x"]])) {
@@ -455,7 +457,7 @@ data_to_series <- function(data, mapping, type, fast = FALSE, ...) {
       data[["y"]] <- as.numeric(as.factor(data[["y"]])) - 1
     }
   }
-  
+
   # x
   if (has_name(mapping, "x")) {
     if (is.Date(data[["x"]])) {
@@ -465,7 +467,7 @@ data_to_series <- function(data, mapping, type, fast = FALSE, ...) {
       data[["x"]] <- NULL
     }
   }
-  
+
   # color
   if (has_name(mapping, "color")) {
     if (type == "treemap") {
@@ -476,26 +478,27 @@ data_to_series <- function(data, mapping, type, fast = FALSE, ...) {
   } else if (has_name(data, "color")) {
     data <- rename(data, colorv = .data$color)
   }
-  
+
   # size
   if (type %in% c("bubble", "scatter")) {
     if (has_name(mapping, "size")) {
       data <- mutate(data, z = .data$size)
     }
   }
-  
+
   # group
   if (!has_name(mapping, "group")) {
     data[["group"]] <- "group"
   }
-  
+
   if (isTRUE(fast)) {
     # pre-convert data to json
-    data <- data %>% 
-      group_by(.data$group) %>% 
-      do(data = jsonlite::toJSON(select(., -.data$group), 
-                                 dataframe = "rows", 
-                                 verbatim = TRUE)) %>% 
+    data <- data %>%
+      group_by(.data$group) %>%
+      do(data = jsonlite::toJSON(select(., -.data$group),
+        dataframe = "rows",
+        verbatim = TRUE
+      )) %>%
       ungroup()
   } else {
     data <- data %>%
@@ -503,25 +506,25 @@ data_to_series <- function(data, mapping, type, fast = FALSE, ...) {
       do(data = list_parse(select(., -.data$group))) %>%
       ungroup()
   }
-  
+
   data$type <- type
-  
+
   if (length(list(...)) > 0) {
     data <- add_arg_to_df(data, ...)
   }
-  
+
   if (has_name(mapping, "group") & !has_name(list(...), "name")) {
     data <- rename(data, name = .data$group)
   }
-  
+
   series <- list_parse(data)
-  
+
   series
 }
 
 data_to_options <- function(data, type) {
   opts <- list()
-  
+
   # x
   if (has_name(data, "x")) {
     if (is.Date(data[["x"]])) {
@@ -532,7 +535,7 @@ data_to_options <- function(data, type) {
       opts$xAxis_type <- "linear"
     }
   }
-  
+
   # y
   if (has_name(data, "x")) {
     if (is.Date(data[["y"]])) {
@@ -543,14 +546,14 @@ data_to_options <- function(data, type) {
       opts$yAxis_type <- "linear"
     }
   }
-  
+
   # showInLegend
   opts$series_plotOptions_showInLegend <- "group" %in% names(data)
-  
+
   # colorAxis
   opts$add_colorAxis <-
     (type == "treemap" & "color" %in% names(data)) | (type == "heatmap")
-  
+
   # heatmap
   if (type == "heatmap") {
     if (!is.numeric(data[["x"]])) {
@@ -560,7 +563,7 @@ data_to_options <- function(data, type) {
       opts$yAxis_categories <- levels(as.factor(data[["y"]]))
     }
   }
-  
+
   opts
 }
 
@@ -573,15 +576,15 @@ data_to_options <- function(data, type) {
 #' @export
 hc_rm_series <- function(hc, names = NULL) {
   stopifnot(!is.null(names))
-  
+
   positions <- hc$x$hc_opts$series %>%
     map("name") %>%
     unlist()
-  
+
   position <- which(positions %in% names)
-  
+
   hc$x$hc_opts$series[position] <- NULL
-  
+
   hc
 }
 
@@ -602,13 +605,13 @@ hc_rm_series <- function(hc, names = NULL) {
 #' @export
 hc_add_series_list <- function(hc, x) {
   assertthat::assert_that(is.highchart(hc), (is.list(x) | is.data.frame(x)))
-  
+
   if (is.data.frame(x)) {
     x <- list_parse(x)
   }
-  
+
   hc$x$hc_opts$series <- append(hc$x$hc_opts$series, x)
-  
+
   hc
 }
 
@@ -623,7 +626,7 @@ hc_add_series_list <- function(hc, x) {
 #' @param hc A `highchart` `htmlwidget` object.
 #' @param series The name of type of series to apply the event.
 #' @param event The name of event: click, mouseOut,  mouseOver. See
-#'   \url{http://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.select}
+#'   \url{https://api.highcharts.com/highcharts/plotOptions.areasplinerange.point.events.select}
 #'   for more details.
 #'
 #' @note Event details are accessible from hc_name_EventType, i.e. if a highchart is rendered against output$my_hc and
@@ -639,9 +642,9 @@ hc_add_event_point <- function(hc, series = "series", event = "click") {
 
   if (typeof Shiny != 'undefined') { Shiny.onInputChange(this.series.chart.renderTo.id + '_' + '", event, "', pointinfo); }
 }")
-  
+
   fun <- JS(fun)
-  
+
   eventobj <- structure(
     list(structure(
       list(structure(
@@ -655,12 +658,12 @@ hc_add_event_point <- function(hc, series = "series", event = "click") {
     )),
     .Names = series
   )
-  
+
   hc$x$hc_opts$plotOptions <- rlist::list.merge(
     hc$x$hc_opts$plotOptions,
     eventobj
   )
-  
+
   hc
 }
 
@@ -675,7 +678,7 @@ hc_add_event_series <- function(hc, series = "series", event = "click") {
 
 }")
   fun <- JS(fun)
-  
+
   eventobj <- structure(
     list(structure(
       list(structure(
@@ -686,29 +689,29 @@ hc_add_event_series <- function(hc, series = "series", event = "click") {
     )),
     .Names = series
   )
-  
+
   hc$x$hc_opts$plotOptions <- rlist::list.merge(
     hc$x$hc_opts$plotOptions,
     eventobj
   )
-  
+
   hc
 }
 
 #' Helper to add annotations from data frame or list
-#' 
-#' @param hc A `highchart` `htmlwidget` object. 
-#' @param ... Arguments defined in \url{https://api.highcharts.com/highcharts/annotations}. 
-#' 
+#'
+#' @param hc A `highchart` `htmlwidget` object.
+#' @param ... Arguments defined in \url{https://api.highcharts.com/highcharts/annotations}.
+#'
 #' @export
 hc_add_annotation <- function(hc, ...) {
   assertthat::assert_that(is.highchart(hc))
-  
+
   hc$x$hc_opts[["annotations"]] <- append(
     hc$x$hc_opts[["annotations"]],
     list(list(...))
   )
-  
+
   hc
 }
 
@@ -719,13 +722,13 @@ hc_add_annotation <- function(hc, ...) {
 #' @export
 hc_add_annotations <- function(hc, x) {
   assertthat::assert_that(is.highchart(hc), (is.list(x) | is.data.frame(x)))
-  
+
   if (is.data.frame(x)) {
     x <- list_parse(x)
   }
-  
+
   hc$x$hc_opts[["annotations"]] <- append(hc$x$hc_opts[["annotations"]], x)
-  
+
   hc
 }
 
@@ -747,21 +750,19 @@ hc_add_annotations <- function(hc, x) {
 #' hchart(mpg, "point", hcaes(displ, hwy, group = drv), regression = TRUE) %>%
 #'   hc_colors(c("#d35400", "#2980b9", "#2ecc71")) %>%
 #'   hc_add_dependency("plugins/highcharts-regression.js")
-#'   
-#' @details See `vignette("modules")`   
+#' @details See `vignette("modules")`
 #' @importFrom purrr map_chr
 #' @importFrom htmltools htmlDependency
 #' @importFrom yaml yaml.load_file
 #' @export
 hc_add_dependency <- function(hc, name = "plugins/annotations.js") {
-  
   stopifnot(!is.null(name))
-  
+
   yml <- system.file("htmlwidgets/highchart.yaml", package = "highcharter")
   yml <- yaml.load_file(yml)[[1]]
-  
+
   hc_ver <- map_chr(yml, c("version"))[map_chr(yml, c("name")) == "highcharts"]
-  
+
   dep <- htmlDependency(
     name = basename(name),
     version = hc_ver,
@@ -771,8 +772,8 @@ hc_add_dependency <- function(hc, name = "plugins/annotations.js") {
     )),
     script = basename(name)
   )
-  
+
   hc$dependencies <- c(hc$dependencies, list(dep))
-  
+
   hc
 }
